.tabs {
	padding-left:10px;
	padding-right:10px;
}

.checkypanels {
	min-height: 250px;
}

.tabcontent{
	padding-left:20px;
	padding-top:20px;
	padding-bottom:20px;
}

.hboxcontent{
	padding-bottom:10px;

}